Name:           libarchive3
Version:        3.1.2
Release:        0.1%{?dist}
Summary:        A library for handling streaming archive formats
Group:          System Environment/Libraries
License:        BSD
URL:            http://www.libarchive.org/
Source0:        http://www.libarchive.org/downloads/libarchive-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: bison
BuildRequires: sharutils
BuildRequires: zlib-devel
BuildRequires: bzip2-devel
BuildRequires: xz-devel
BuildRequires: lzo-devel
BuildRequires: e2fsprogs-devel
BuildRequires: libacl-devel
BuildRequires: libattr-devel
BuildRequires: openssl-devel
BuildRequires: libxml2-devel
BuildRequires: valgrind


# CVE-2013-0211 libarchive: read buffer overflow on 64-bit systems
# https://bugzilla.redhat.com/show_bug.cgi?id=927105
Patch0: libarchive-3.1.3-CVE-2013-0211_read_buffer_overflow.patch

# upstream ~> 26629c191a & b539b2e597 & 9caa49246
Patch1: libarchive-3.1.2-testsuite.patch

# fix not working saving/restoring acl
# ~> downstream
Patch2: libarchive-3.1.2-acl.patch

# ~> upstream patches: 3865cf2b e6c9668f 24f5de65
Patch3: libarchive-3.1.2-security-rhbz-1216891.patch

# upstream: e65bf287
Patch4: libarchive-3.1.2-mtree-fix.patch

%description
Libarchive is a programming library that can create and read several different
streaming archive formats, including most popular tar variants, several cpio
formats, and both BSD and GNU ar variants. It can also write shar archives and
read ISO9660 CDROM images and ZIP archives.


%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       pkgconfig

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package -n     bsdtar3
Summary:        Manipulate tape archives
Group:          Applications/Archiving
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n bsdtar3
The bsdtar package contains standalone bsdtar utility split off regular
libarchive packages.


%package -n     bsdcpio3
Summary:        Copy files to and from archives
Group:          Applications/Archiving
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n bsdcpio3
The bsdcpio package contains standalone bsdcpio utility split off regular
libarchive packages.


%prep
%setup -qn libarchive-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1


%build
#build/autogen.sh
%configure --disable-static --disable-rpath
# remove rpaths
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

test -z "$V" && verbose_make="V=1"
make %{?_smp_mflags} $verbose_make


%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
find %{buildroot} -name '*.la' -exec rm -f {} ';'

# Rename files, so they don't clash with original libarchive.
for bin in %{buildroot}%{_bindir}/*
do
    mv -fv "${bin}" "${bin}3"
done

for man in $(find %{buildroot}%{_mandir} -type f)
do
    dir=$(dirname "$man")
    name=$(basename "$man" | sed -e 's!\..*$!!g')
    ext=$(basename "$man"  | sed -e 's!^.*\.!!g')
    mv -fv "${man}" "${dir}/${name}3.${ext}"
done

for header in $(find %{buildroot}%{_includedir} -type f)
do
    dir=$(dirname "$header")
    name=$(basename "$header" | sed -e 's!\..*$!!g')
    ext=$(basename "$header"  | sed -e 's!^.*\.!!g')
    mv -fv "${header}" "${dir}/${name}3.${ext}"
done

mv -fv %{buildroot}%{_libdir}/libarchive.so %{buildroot}%{_libdir}/libarchive3.so
mv -fv %{buildroot}%{_libdir}/pkgconfig/libarchive.pc \
       %{buildroot}%{_libdir}/pkgconfig/libarchive3.pc
sed -i -e 's!l.*archive!&3!g' %{buildroot}%{_libdir}/pkgconfig/libarchive3.pc


%check
run_testsuite()
{
    LD_LIBRARY_PATH=`pwd`/.libs make check -j1
    res=$?
    echo $res
    if [ $res -ne 0 ]; then
        # error happened - try to extract in koji as much info as possible
        cat test-suite.log
        echo "========================="
        err=`cat test-suite.log | grep "Details for failing tests" | cut -d: -f2`
        for i in $err; do
            find $i -printf "%p\n    ~> a: %a\n    ~> c: %c\n    ~> t: %t\n    ~> %s B\n"
            echo "-------------------------"
            cat $i/*.log
        done
        return 1
    else
        return 0
    fi
}

# On a ppc/ppc64 is some race condition causing 'make check' fail on ppc
# when both 32 and 64 builds are done in parallel on the same machine in
# koji.  Try to run once again if failed.
%ifarch ppc
run_testsuite || run_testsuite
%else
# On ix86 the xar write test may fail.  Running it with valgrind makes it pass.
run_testsuite || valgrind ./libarchive_test
%endif

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%files
%{!?_licensedir:%global license %%doc}
%license COPYING
%doc README NEWS
%{_libdir}/libarchive.so.13*
%{_mandir}/*/cpio*3.*
%{_mandir}/*/mtree*3.*
%{_mandir}/*/tar*3.*

%files devel
%{_includedir}/*3.h
%{_mandir}/*/archive*3.*
%{_mandir}/*/libarchive*3.*
%{_libdir}/libarchive3.so
%{_libdir}/pkgconfig/libarchive3.pc

%files -n bsdtar3
%{!?_licensedir:%global license %%doc}
%license COPYING
%doc README NEWS
%{_bindir}/bsdtar3
%{_mandir}/*/bsdtar*3.*

%files -n bsdcpio3
%{!?_licensedir:%global license %%doc}
%license COPYING
%doc README NEWS
%{_bindir}/bsdcpio3
%{_mandir}/*/bsdcpio*3.*


%changelog
* Thu Mar 17 2016 Neal Gompa <ngompa13{%}gmail{*}com> - 3.1.2-0.1
- Backport to EL5

* Mon Mar 07 2016 Björn Esser <fedora@besser82.io> - 3.1.2-1
- initial epel-release (#1315307)
